% Process_and_Plot_IECC_Climate_Zones_2012.m
% 20200110
% Casey D. Burleyson
% Pacific Northwest National Laboratory
% Create maps of the 2012 IECC climate zones.

warning off all; clear all; close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN USER INPUT SECTION               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set processing and plotting flags:
process_data = 1; % (1 = yes)
save_images = 1; % (1 = yes)

% Set the data input and output directories:
data_input_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/IECC_Climate_Zones/';
data_output_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/IECC_Climate_Zones/';
image_output_dir = '/Users/burl878/OneDrive - PNNL/Documents/IMMM/Data/IECC_Climate_Zones/Figures/';

% Set the geographic boundaries on the plots:
lat_min = 24.75;
lat_max = 49.75;
lon_min = -125;
lon_max = -66.5;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              END USER INPUT SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN PROCESSING SECTION               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if process_data == 1
   load([data_input_dir,'Code/shapefile_counties.mat'],'shapefile_counties');
   for row = 1:size(shapefile_counties,1)
       county_FIPS_vector(row,1) = shapefile_counties(row,1).county_FIPS;
   end
   clear row
    
   [~,~,County_Raw] = xlsread([data_input_dir,'county_IECC_climate_zones_2012.xlsx'],'Counties','A1:F3143');
   for row = 2:size(County_Raw,1)
       County_Mapping(row-1,1) = County_Raw{row,3};
       County_Mapping(row-1,2) = County_Raw{row,5};
       County_Mapping(row-1,3) = County_Raw{row,6};
       County_Mapping(row-1,4) = Combined_IECC_CZ_CONUS(County_Raw{row,5},County_Raw{row,6});
   end
   clear row County_Raw
      
   for row = 1:size(County_Mapping,1)
       index = find(county_FIPS_vector(:) == County_Mapping(row,1));
       County_Mapping(row,5) = index;
       clear index
   end
   clear row county_FIPS_vector
   
   save([data_output_dir,'county_IECC_climate_zones_2012.mat'],'County_Mapping','shapefile_counties');
else
   load([data_output_dir,'county_IECC_climate_zones_2012.mat']);
end 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               END PROCESSING SECTION                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%              BEGIN PLOTTING SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
a = figure('Color',[1 1 1]); set(a,'Position',get(0,'Screensize')); hold on; 
ax1 = usamap([lat_min lat_max],[lon_min lon_max]); colormap(ax1,flipud(jet(15)));
states = shaperead('usastatelo','UseGeoCoords',true,'Selector',{@(name)~any(strcmp(name,{'Alaska','Hawaii'})),'Name'});
faceColors = makesymbolspec('Polygon',{'INDEX',[1 numel(states)],'FaceColor',polcmap(numel(states))});
faceColors.FaceColor{1,3} = faceColors.FaceColor{1,3}./faceColors.FaceColor{1,3};
geoshow(ax1,states,'DisplayType','polygon','SymbolSpec',faceColors,'LineWidth',1,'LineStyle','-');
for row = 1:size(County_Mapping,1)
    patchm(shapefile_counties(County_Mapping(row,5),1).lat_vector,shapefile_counties(County_Mapping(row,5),1).lon_vector,0,'FaceVertexCData',County_Mapping(row,4),'FaceColor','flat');
end
set(gca,'clim',[1,16]);
colo1 = colorbar('ytick',[1.5:1:15.5],'YTickLabel',{'1A','2A','2B','3A','3B','3C','4A','4B','4C','5A','5B','6A','6B','7A','7B','7C'});
set(get(colo1,'ylabel'),'String',{''},'FontSize',21);
tightmap; framem on; gridm off; mlabel off; plabel off;
set(gca,'LineWidth',3,'FontSize',21,'Box','on','Layer','top');
title(['2012 IECC Climate Zones'],'FontSize',24);
if save_images == 1
   set(gcf,'Renderer','zbuffer'); set(gcf,'PaperPositionMode','auto');
   print(a,'-dpng','-r300',[image_output_dir,'County_IECC_Climate_Zones_2012.png']);
   close(a);
end
clear a ax1 colo1 row faceColors states
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               END PLOTTING SECTION                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                BEGIN CLEANUP SECTION                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear data_input_dir image_output_dir save_images lat_min lat_max lon_min lon_max process_data data_output_dir shapefile_counties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                 END CLEANUP SECTION                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%